#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const minimist = require("minimist");
const cmd_build_1 = require("./cmd-build");
const cmd_docker_1 = require("./cmd-docker");
const cmd_k8s_1 = require("./cmd-k8s");
const cmd_misc_1 = require("./cmd-misc");
const cmd_realm_1 = require("./cmd-realm");
const cmd_storage_1 = require("./cmd-storage");
const argv = minimist(process.argv.slice(2), { '--': true });
const allCmds = {
    ...cmd_build_1.cmds,
    ...cmd_docker_1.cmds,
    ...cmd_k8s_1.cmds,
    ...cmd_misc_1.cmds,
    ...cmd_realm_1.cmds,
    ...cmd_storage_1.cmds
};
run(argv);
async function run(agv) {
    const cmdName = argv._[0]; // 'kcreate', 'nclean'
    try {
        const fn = (allCmds && cmdName) ? allCmds[cmdName] : null;
        if (!fn) {
            throw new Error(`comamnd ${argv._} unknown`);
        }
        // remove the "routing commands" so that the command fn get the specialize context
        const miniArgv = { ...argv }; // shallow copy
        miniArgv._ = miniArgv._.slice(1); // new array
        // add the rawArgv from same index in case the fn needs it
        const rawArgv = process.argv.slice(3);
        await fn(miniArgv, rawArgv);
    }
    catch (ex) {
        console.log(`${ex}`);
    }
}
