"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const main_1 = require("../main");
const session_1 = require("../session");
exports.cmds = {
    dpush, dbuild
};
// --------- Docker CMDs --------- //
// push the docker image to the remote cloud (today, gcloud)
async function dpush(argv) {
    const servicesStr = argv._[0];
    const realm = main_1.assertRealm(await main_1.getCurrentRealm());
    await main_1.push(realm, servicesStr);
}
async function dbuild(argv) {
    const blockStr = argv._[0];
    // update the version
    await main_1.updateVersions();
    const realm = main_1.assertRealm(await main_1.getCurrentRealm());
    const dockerBlocks = await main_1.loadDockerBlocks();
    const nameFilterSet = (blockStr) ? new Set(main_1.asNames(blockStr)) : null;
    for (let dockerBlock of Object.values(dockerBlocks)) {
        if (nameFilterSet === null || nameFilterSet.has(dockerBlock.name)) {
            await main_1.buildDockerImage(dockerBlock);
            console.log();
        }
    }
    if (session_1.hasSessionState('NO_LOCAL_REGISTRY')) {
        if (realm.type === 'local') {
            console.log('\n\nWARNING - No Local Registry (http://localhost:5000/) - Images were not pushed to local registry');
            console.log(`\t  Will NOT be able to deploy to local kubernetes (e.g., 'npm run vdev kcreate' will fail)`);
            console.log(`\n\tTips:\n\t   Start local docker registry: 'docker run -d -p 5000:5000 --restart=unless-stopped --name registry registry'`);
            console.log(`\t   Re-run dbuild: 'npm run vdev dbuild'\n\n`);
        }
    }
}
// --------- /Docker CMDs --------- //
