"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const main_1 = require("../main");
exports.cmds = {
    sls, scp, sdown, sup
};
// --------- Commands --------- //
async function sls(argv) {
    const pathInfoStr = argv._[0];
    if (!pathInfoStr) {
        throw new Error(`comman 'ls' must have a path to list`);
    }
    const files = await main_1.list(main_1.parsePathInfo(pathInfoStr));
    const maxNameLength = maxPropLength(files, 'path');
    files.forEach((f) => {
        const dispName = f.path.padEnd(maxNameLength + 5);
        const size = (f.size != null) ? f.size : -1;
        console.log(`${dispName} ${formatSize(size)}`);
    });
}
async function scp(argv) {
    const fromPathInfo = argv._[0];
    const toPathInfo = argv._[1];
    if (!fromPathInfo || !toPathInfo) {
        throw new Error(`command 'cp' must have a fromPath and toPath`);
    }
    const files = await main_1.copy(main_1.parsePathInfo(fromPathInfo), main_1.parsePathInfo(toPathInfo));
}
async function sdown(argv) {
    const pathInfoStr = argv._[0];
    if (!pathInfoStr) {
        throw new Error(`comman 'down' must have a remote path to download`);
    }
    // TODO: need to support give a destination
    const destDir = `${os_1.homedir()}/Downloads/`;
    await main_1.download(main_1.parsePathInfo(pathInfoStr), destDir);
}
async function sup(argv) {
    const file = argv._[0];
    const pathInfoStr = argv._[1];
    if (!file || !pathInfoStr) {
        throw new Error(`command 'up' must have a local file and destination path`);
    }
    const r = await main_1.upload(file, main_1.parsePathInfo(pathInfoStr));
}
// --------- /Commands --------- //
const units = { Gb: 3, Mb: 2 };
// Format a size in bytes in readable Mb or Gb
function formatSize(size) {
    let l = 1000;
    let name = 'Kb';
    for (name in units) {
        l = Math.pow(1000, units[name]);
        if (size > l) {
            break;
        }
    }
    const relSize = Math.round(size * 10 / l) / 10;
    return `${relSize} ${name}`;
}
function maxPropLength(items, name) {
    let m = -1;
    for (let item of items) {
        const val = item[name];
        if (val != null && val.length != null && val.length > m) {
            m = val.length;
        }
    }
    return m;
}
