"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_bucket_1 = require("cloud-bucket");
const utils_1 = require("./utils");
// --------- Public list/copy/del/download/upload --------- //
async function list(pathInfo) {
    const bucket = await getBucketFromPathInfo(pathInfo);
    const result = await bucket.list(pathInfo.path);
    return result;
}
exports.list = list;
async function copy(from, to) {
    const files = await list(from);
    const destBucket = await getBucketFromPathInfo(to);
    // FIXME: Need to be implemented
}
exports.copy = copy;
async function download(from, destDir) {
    if (from.path == null) {
        throw new Error(`Cannot download - undefined remote path: ${from.store}:${from.path}`);
    }
    const bucket = await getBucketFromPathInfo(from);
    return bucket.download(from.path, destDir);
}
exports.download = download;
async function upload(localFile, dest) {
    if (dest.path == null) {
        throw new Error(`Cannot download - undefined remote path: ${dest.store}:${dest.path}`);
    }
    const bucket = await getBucketFromPathInfo(dest);
    return bucket.upload(localFile, dest.path);
}
exports.upload = upload;
// --------- /Public list/cp/del/download/upload ------, --- //
// --------- public PathInfo --------- //
const formatInfo = `'storename:path' or just 'storename'`;
function parsePathInfo(storeAndPathStr) {
    if (storeAndPathStr == null || storeAndPathStr.length == 0) {
        throw new Error(`gs need to have a path like ${formatInfo}`);
    }
    const storeAndPath = storeAndPathStr.split(':');
    if (storeAndPath.length > 2) {
        throw new Error(`Path ${storeAndPathStr} is invalid, needs to be of format like  ${formatInfo}`);
    }
    const [store, path] = storeAndPath;
    return { store, path };
}
exports.parsePathInfo = parsePathInfo;
// --------- /public PathInfo --------- //
// --------- Private Utils --------- //
async function getBucketFromPathInfo(pathInfo) {
    const bucketCfgs = await loadRawConfig();
    // TODO: Needs to recognize the config from gcp vs aws (for now, assume gcp)
    const rawCfg = bucketCfgs[pathInfo.store];
    return cloud_bucket_1.getBucket(rawCfg);
}
async function loadRawConfig() {
    let vdevBuckets = await utils_1.loadYaml('vdev-buckets.yaml');
    const confs = vdevBuckets.buckets;
    // add the .name to each bucket info
    for (let name in confs) {
        confs[name].name = name;
    }
    return confs;
}
// --------- /Private Utils --------- //
