"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const awsHooks = __importStar(require("./hook-aws"));
const gcpHooks = __importStar(require("./hook-gcp"));
const hooksDic = new Map();
//#region    ---------- Initialize the Hook Registry ---------- 
const hookObjByType = {
    'aws': awsHooks,
    'gcp': gcpHooks
};
for (const k of Object.keys(hookObjByType)) {
    const type = k; // Note: might have a better way to get types from hookObjByType
    const fnByName = hookObjByType[type];
    for (const key in fnByName) {
        // TODO: need some validations
        const name = key;
        const fn = fnByName[name];
        registerHook(type, name, fn);
    }
}
//#endregion ---------- /Initialize the Hook Registry ---------- 
async function callHook(realm, name, ...args) {
    const fn = getHook(realm.type, name);
    if (fn) {
        return fn(realm, ...args);
    }
}
exports.callHook = callHook;
function getHook(type, name) {
    const fnDic = hooksDic.get(type);
    return (fnDic) ? fnDic.get(name) : undefined;
}
function registerHook(type, name, fn) {
    let fnDic = hooksDic.get(type);
    if (fnDic == null) {
        fnDic = new Map();
        hooksDic.set(type, fnDic);
    }
    fnDic.set(name, fn);
}
