"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs-extra-plus"));
const p_spawn_1 = require("p-spawn");
const defaultPsqlOptions = {
    toConsole: true
};
// NOTE: for now, ignore pgOpts.pwd
async function psqlImport(pgOpts, filePaths) {
    pgOpts = { ...defaultPsqlOptions, ...pgOpts };
    const items = [];
    if (typeof filePaths === "string") {
        filePaths = [filePaths];
    }
    var baseArgs = buildPgArgs(pgOpts);
    var cmd = "psql";
    // TODO: add the password env var.
    for (let file of filePaths) {
        let args = baseArgs.slice(0);
        args.push("-f", file);
        if (pgOpts.toConsole) {
            console.log("will execute >> " + cmd + " " + args.join(" "));
        }
        const spawnOptions = buildSpawnOptions(pgOpts);
        const p = await p_spawn_1.spawn(cmd, args, spawnOptions);
        const item = { file };
        item.stdout = p.stdout;
        if (p.stderr) {
            item.stderr = p.stderr.trim();
        }
        items.push(item);
        if (item.stderr) {
            const err = new Error(`psqlImport ERROR for file ${file}:\n${item.stderr}`);
            err.items = items;
            throw err;
        }
    }
    return items;
}
exports.psqlImport = psqlImport;
// pgdump with no-owner, no-acl
async function psqlExport(pgOpts, filepath) {
    var defaultArgs = ["--no-owner", "--no-acl"];
    var baseArgs = buildPgArgs(pgOpts);
    var args = [];
    var cmd = "pg_dump";
    args = defaultArgs.concat(baseArgs);
    var fStream = fs.createWriteStream(filepath, { flags: 'w' });
    console.log("will execute >> " + cmd + " " + args.join(" ") + "\n\t into " + filepath);
    var env = Object.assign({}, process.env);
    env.PGPASSWORD = pgOpts.pwd;
    await p_spawn_1.spawn(cmd, args, {
        env,
        onStdout: (data) => {
            fStream.write(data);
        }
    });
}
exports.psqlExport = psqlExport;
async function pgTest(pgOpts) {
    const status = await pgStatus(pgOpts);
    if (!status.accepting) {
        return { success: false, message: status.message };
    }
    // --command="SELECT version();
    // var args = buildPgArgs(pgOpts);
    var args = buildPgArgs(pgOpts);
    args.push("--command=SELECT version()");
    const p = await p_spawn_1.spawn('psql', args, { capture: ['stdout', 'stderr'], ignoreFail: true });
    if (p.code === 0) {
        return { success: true, message: p.stdout.trim() };
    }
    else {
        const r = { success: false, message: p.stdout };
        if (p.stderr) {
            r.err = p.stderr.trim();
        }
        return r;
    }
}
exports.pgTest = pgTest;
/** Return the status of a pg database process (without the database) */
async function pgStatus(pgOpts) {
    var args = buildPgArgs(pgOpts);
    //args.push('-q'); // for the quiet mode, we just need to result code
    const p = await p_spawn_1.spawn('pg_isready', args, { ignoreFail: true, capture: ['stdout', 'stderr'] });
    const code = p.code;
    const message = p.stdout.trim();
    const accepting = (0 === p.code) ? true : false;
    return { accepting, message, code };
}
exports.pgStatus = pgStatus;
// --------- /Utils public API --------- //
// --------- Private Utils --------- //
function buildSpawnOptions(pgOpts) {
    let spawnOptions = { capture: ['stdout', 'stderr'] };
    if (pgOpts.toConsole) {
        spawnOptions.toConsole = true;
    }
    return spawnOptions;
}
// private: Build a cmd line argument list from a pgOpts {user, db[, pwd][, host][, port: 5432]} and make it an command line arguments
function buildPgArgs(pgOpts) {
    var cmdArgs = [];
    if (pgOpts.user) {
        cmdArgs.push("-U", pgOpts.user);
    }
    if (pgOpts.db) {
        cmdArgs.push("-d", pgOpts.db);
    }
    if (pgOpts.host) {
        cmdArgs.push("-h", pgOpts.host);
    }
    if (pgOpts.port) {
        cmdArgs.push("-p", pgOpts.port);
    }
    return cmdArgs;
}
// --------- /Private Utils --------- //
