"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs-extra-plus"));
const handlebars = __importStar(require("handlebars"));
const os_1 = require("os");
const path_1 = require("path");
const utils_1 = require("./utils");
async function render(templateString, data) {
    const hbs = getHandlebars();
    const tmpl = hbs.compile(templateString, { noEscape: true });
    const outContent = tmpl(data);
    return outContent;
}
exports.render = render;
async function loadTemplatizedYaml(path, data) {
    try {
        const stringContent = await fs.readFile(path, 'utf8');
        const content = await render(stringContent, data);
        return utils_1.yaml(content);
    }
    catch (ex) {
        console.log(`ERROR - Cannot load ${path_1.resolve(path)}\n\tcause ${ex}`);
        throw ex;
    }
}
exports.loadTemplatizedYaml = loadTemplatizedYaml;
// --------- Handlebars Factory --------- //
let _handlebars = null;
// Initial
function getHandlebars() {
    if (_handlebars) {
        return _handlebars;
    }
    // encode64
    handlebars.registerHelper('encode64', function (arg1, arg2) {
        let val;
        let opts;
        // if we do not have two args, then, it is a regular helper
        if (arg2 === undefined) {
            opts = arg1;
            val = opts.fn(this);
        }
        // if we have two args, then, the first is the value
        else {
            val = arg1;
            opts = arg2;
        }
        const b64 = Buffer.from(val).toString('base64');
        return b64;
    });
    handlebars.registerHelper('username', function () {
        const username = os_1.userInfo().username;
        return username;
    });
    // return the absolute dir of the project (where the script is being run) (with an ending '/')
    handlebars.registerHelper('projectDir', function () {
        return path_1.resolve('./') + '/';
    });
    handlebars.registerHelper('assign', function (varName, varValue, options) {
        if (!options.data.root) {
            options.data.root = {};
        }
        options.data.root[varName] = varValue;
    });
    handlebars.registerHelper('assignJsonValue', function (varName, jsonFile, namePath, options) {
        if (!options.data.root) {
            options.data.root = {};
        }
        // handlebars helper does not support async
        const obj = fs.readJsonSync(jsonFile);
        const val = utils_1.findVal(obj, namePath);
        options.data.root[varName] = val;
    });
    _handlebars = handlebars;
    return _handlebars;
}
// --------- /Handlebars Factory --------- //
