import { BaseObj } from './base';
export interface Block extends BaseObj {
    name: string;
    dir: string;
    webBundles?: WebBundle[];
    baseDistDir?: string;
    dbuildDependencies?: string | string[];
    [key: string]: any;
}
export interface WebBundle {
    name: string;
    /** The entries, support wild cards, to be compiled */
    entries: string | string[];
    /** To specify glob/files to watch in place of the entries (only used in watch mode, and not for .js/.ts) */
    watch?: string | string[];
    rollupOptions?: any;
    dist: string;
    type?: string;
    dir?: string;
}
export declare type BlockByName = {
    [name: string]: Block;
};
export declare function updateVersions(config?: any): Promise<void>;
export declare function cleanNodeFiles(): Promise<void>;
/**
 *
 * @param names List of block name or block/bundle names
 */
export declare function buildBlocksOrBundles(names: string[]): Promise<void>;
export declare function watchBlock(blockName: string): Promise<void>;
export interface BuildOptions {
    watch?: boolean;
    full?: boolean;
    onlyBundleName?: string;
}
/**
 * Build a and block and eventually a bundle
 * @param blockName
 * @param opts
 */
export declare function buildBlock(blockName: string, opts?: BuildOptions): Promise<void>;
export declare function loadDockerBlocks(): Promise<BlockByName>;
export declare function loadBlocks(): Promise<BlockByName>;
export declare function loadBlock(name: string): Promise<Block>;
/**
 * Special resolve that
 *   - if finalPath null, then, return dir.
 *   - resolve any path to dir if it starts with './' or '../',
 *   - absolute path if it starts with '/'
 *   - baseDir if the path does not start with either '/' or './'
 * @param baseDir
 * @param dir
 * @param finalPath dir or file path
 */
export declare function specialPathResolve(baseDir: string, dir: string, finalPath?: string): string;
