"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs-extra-plus"));
const jsyaml = __importStar(require("js-yaml"));
const strip_json_comments_1 = __importDefault(require("strip-json-comments"));
/**
 * Split the eventual comman deliminated string as array of trim items.
 * If array just return the array, if null, return empty array
 * @param srcNames comma deliminated, single name, or array of names
 */
function asNames(srcNames) {
    if (srcNames) {
        if (typeof srcNames === 'string') {
            return srcNames.split(',').map((s) => s.trim());
        }
        else {
            return srcNames;
        }
    }
    else {
        return [];
    }
}
exports.asNames = asNames;
// --------- /Lang & Type Utils --------- //
// --------- Utils --------- //
async function yaml(content) {
    const yamlObj = jsyaml.load(content);
    if (!yamlObj) {
        throw new Error(`Could not load yaml`);
    }
    return yamlObj;
}
exports.yaml = yaml;
async function loadYaml(path) {
    const yamlContent = await fs.readFile(path, 'utf8');
    return yaml(yamlContent);
}
exports.loadYaml = loadYaml;
async function readJsonFileWithComments(path) {
    const content = await fs.readFile(path, 'utf8');
    return JSON.parse(strip_json_comments_1.default(content));
}
exports.readJsonFileWithComments = readJsonFileWithComments;
async function wait(ms) {
    return new Promise(function (resolve) {
        setTimeout(() => { resolve(); }, ms);
    });
}
exports.wait = wait;
// return now in milliseconds using high precision
function now() {
    var hrTime = process.hrtime();
    return hrTime[0] * 1000 + hrTime[1] / 1000000;
}
exports.now = now;
async function printLog(txt, start, dist) {
    const timeStr = Math.round(now() - start) + 'ms';
    let msg = `${txt} - `;
    if (dist == null) {
        msg += timeStr;
    }
    else {
        const distExists = await fs.pathExists(dist);
        if (distExists) {
            let size = (await fs.stat(dist)).size;
            size = Math.round(size / 1000.0);
            msg += `${dist} - ${timeStr} - ${size} kb`;
        }
        else {
            msg += `${dist} - ${timeStr} - ... watch mode started ...`;
        }
    }
    console.log(msg);
}
exports.printLog = printLog;
async function prompt(message) {
    // console.log(`\n${message}: `);
    process.stdout.write(`\n${message}: `);
    return new Promise(function (resolve, reject) {
        process.stdin.resume();
        process.stdin.setEncoding('utf8');
        process.stdin.on('data', function (text) {
            process.stdin.pause();
            resolve(text.toString().trim());
        });
    });
}
exports.prompt = prompt;
/** Attempted to return the obj value given a dottedNamePath (i.e. 'author.name').
 * @returns undefined if nothing found or obj or dottedNamePath is null/undefined. Return obj if dottedNamePath == ''.
 **/
function findVal(obj, dottedNamePath) {
    if (obj == null || dottedNamePath == null) {
        return;
    }
    if (dottedNamePath.trim() === '') {
        return obj;
    }
    let val = obj;
    const names = dottedNamePath.split('.');
    for (let name of names) {
        val = val[name];
        if (val == null) { // if null or undefined, stop and return
            return val;
        }
    }
    return val;
}
exports.findVal = findVal;
// --------- /Utils --------- //
