"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs-extra-plus"));
const Path = __importStar(require("path"));
const renderer_1 = require("./renderer");
const deepmerge = require("deepmerge");
// --------- /Public Types --------- //
// --------- Public Loaders --------- //
const overwriteMerge = (target, source, options) => source;
/** Parse the ./vdev.yaml and return as is */
async function loadVdevConfig(rootDir) {
    var _a, _b;
    rootDir = rootDir || "./";
    const vdevFile = Path.join(rootDir, 'vdev.yaml');
    //// Get the __version__
    const packageJson = await fs.readJSON('./package.json');
    let __version__ = (_a = packageJson.__version__) !== null && _a !== void 0 ? _a : packageJson.version;
    //// build the data for the vdev template
    // TODO: probably needs to put the other variable from the handlebars helpers here
    const data = { __version__ };
    // NOTE: Here we use the loadTempletezedYaml, but for now, the vdev files are not templates, just the k8s yamls are.
    let vdevObj = await loadVdevFile(vdevFile, true, data);
    // TODO: probably need to do some validate here.
    // load the sub vdev files if defined
    if (vdevObj.vdevFiles) {
        for (const subRelVdevFile of vdevObj.vdevFiles) {
            const subVdevFile = Path.join(rootDir, subRelVdevFile);
            const exists = await fs.pathExists(subVdevFile);
            if (exists) {
                console.log(`INFO - Loading extra vdev file: ${subVdevFile}`);
                try {
                    let subVdevObj = await loadVdevFile(subVdevFile, false, data);
                    vdevObj = deepmerge(vdevObj, subVdevObj, { arrayMerge: overwriteMerge });
                }
                catch (ex) {
                    console.log(`ERROR - Cannot load vdev files ${subVdevFile} (skipping file)\n\tCause: ${ex}`);
                }
            }
        }
    }
    //// Allow the __version__ to be updated
    vdevObj.__version__ = __version__;
    vdevObj.imageTag = (_b = vdevObj.imageTag) !== null && _b !== void 0 ? _b : 'latest';
    return vdevObj;
}
exports.loadVdevConfig = loadVdevConfig;
// --------- /Public Loaders --------- //
/**
 * Load a single vdev yaml file. Can be the base or a sub vdev file
 * @param base If the vdev file is the base (should have more validation)
 */
async function loadVdevFile(vdevFile, base, data) {
    const vdevRawObj = await renderer_1.loadTemplatizedYaml(vdevFile, data);
    // TODO: need to do validation
    return vdevRawObj;
}
